import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id:phoneNumbers

    orientationLock: PageOrientation.LockPortrait

    tools:
        ToolBarLayout {
        visible: true
                ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent === undefined ? undefined : parent.right
        }
    }



    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#247800"
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                color:"#fff"
                text:"Teléfonos Útiles"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                color:"#fff"
                text:"Seleccione un número para llamar"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }

    ListModel {
        id:emergencyNumbersModel
        ListElement {
            icon: "police.png"
            name: "Policia"
            number: "911"
            description:"Atención las 24 horas, envio de patrullas o personal desde la comisaría mas cercana."
        }
        ListElement {
            icon: "same.png"
            name: "SAME"
            number: "107"
            description:"Emergencias médicas, atención las 24 hs, los 365 días del año."
        }
        ListElement {
            icon: "fire.png"
            name: "Bomberos"
            number: "100"
            description:"Emergencias por incendios o rescates, atención las 24 hs, los 365 días del año."
        }
        ListElement {
            icon: "dcivil.png"
            name: "Defensa Civil"
            number: "103"
            description:"Atención las 24 hs., reclamos por accidentes en la vía pública."
        }
        ListElement {
            icon: "info.png"
            name: "Línea Belgrano Norte"
            number: "08007773384"
            description:"Atención al cliente Ferrovías, consulta de horarios, servicio o reclamos."
        }
        ListElement {
            icon: "info.png"
            name: "Línea Belgrano Sur"
            number: "08003330891"
            description:"Centro de Atención al Pasajero, consulta de horarios, servicio o reclamos."
        }
        ListElement {
            icon: "info.png"
            name: "Línea Mitre"
            number: "08003333822"
            description:"Centro de Atención al Pasajero, ubicado en Estación Retiro, Gran Hall."
        }
        ListElement {
            icon: "info.png"
            name: "Línea Roca"
            number: "08003627622 "
            description:"Centro de Atención al Pasajero, consulta de horarios, servicio o reclamos."
        }
        ListElement {
            icon: "info.png"
            name: "Línea Sarmiento"
            number: "08003333822"
            description:"Centro de Atención al Pasajero, ubicado en Estación Once, Hall Central."
        }
        ListElement {
            icon: "info.png"
            name: "Línea Urquiza"
            number: "08005551616"
            description:"Centro de Atención al Pasajero, ubicado en Estación Fco. Lacroze, Andén Nro. 1"
        }
    }

    Component {
        id:emergencyNumbersDelegate

        Item {
            height: 142
            width: parent.width

            BorderImage {
                id: background
                anchors.fill: parent
                // Fill page borders
                anchors.leftMargin: -phoneNumbers.anchors.leftMargin
                anchors.rightMargin: -phoneNumbers.anchors.rightMargin
                visible: mouseArea.pressed
                source: "image://theme/meegotouch-list-fullwidth-background-pressed-center"
            }

            Item {
                id:listItem
                anchors.fill: parent
                Item {
                    id: itemIcon
                    width:96
                    height: 142
                    Image {
                        smooth: true
                        width: 64
                        height: 64
                        source: "images/" + icon
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                    }
                }

                Item {
                    id: itemLabels
                    width: listItem.width - 124
                    height: itemName.height + itemDescription.height
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: itemIcon.right
                    anchors.leftMargin: 8

                    Label {
                        id:itemName
                        text: name + " - " + number
                        font.weight: Font.Bold
                        font.pixelSize: 26
                        width: parent.width
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemDescription
                        text: description
                        anchors.top: itemName.bottom
                        anchors.topMargin: 0
                        font.weight: Font.Normal
                        font.pixelSize: 21
                        width: parent.width - 8
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                }
            }

            Image {
                source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.verticalCenter: parent.verticalCenter
            }


            MouseArea {
                id: mouseArea
                anchors.fill: background
                onClicked: {
                    Qt.openUrlExternally("tel:"+number)
                }
            }
        }
    }

    ListView {
        id:listView
        anchors.top: header.bottom
        anchors.topMargin: 8
        anchors.right: parent.right
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        model:emergencyNumbersModel
        delegate:emergencyNumbersDelegate
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
